@@ -1,3 +1,5 @@
+"""Flask extension which integrates additional loggers with Flask app.
+"""
 
 import logging
 from logging import getLogger, Formatter
@@ -12,9 +14,9 @@ from flask import request, current_app
 
 
 # Universal error message format for custom logger handlers. Any handler who
-# uses this should use the HandlerDataMixin class so that extra data
+# uses this should use the EnvironDataMixin class so that extra data
 # is attached.
-ERROR_FORMAT = '''
+ERROR_FORMAT = """
 ===============================================================================
 Message type:       %(levelname)s
 Location:           %(pathname)s:%(lineno)d
@@ -32,48 +34,54 @@ ERROR:
 
 %(message)s
 ===============================================================================
-'''
+"""
 
 WARNING_FORMAT = (
     '%(asctime)s: %(levelname)s: %(message)s [in %(pathname)s:%(lineno)d]')
 
 
 # default pprint.pformat function to use to output request environ
+# pylint: disable=invalid-name
 pformat = partial(pprint.pformat, indent=4, depth=None)
+# pylint: enable=invalid-name
 
 
 class Logger(object):
+    """Flask Logger extension."""
+
     def __init__(self, app=None):
         self.app = app
 
-        if app: # pragma: no cover
+        if app:  # pragma: no cover
             self.init_app(app)
 
     def init_app(self, app):
+        """Initialize app."""
         app.config.setdefault('CARAFE_LOGGER_ENABLED', True)
 
-        if app.debug or not app.config['CARAFE_LOGGER_ENABLED']: # pragma: no cover
+        if not app.config['CARAFE_LOGGER_ENABLED']:  # pragma: no cover
             return
 
         if app.config.get('CARAFE_LOGGER_RFILE_ENABLED'):
             loggers = ([app.logger] +
-                app.config.get('CARAFE_LOGGER_RFILE_ADD_LOGGERS', []))
+                       app.config.get('CARAFE_LOGGER_RFILE_ADD_LOGGERS', []))
 
             self.add_handlers(
                 loggers, create_rotating_file_handler(app.config))
 
         if app.config.get('CARAFE_LOGGER_SMTP_ENABLED'):
             loggers = ([app.logger] +
-                app.config.get('CARAFE_LOGGER_SMTP_ADD_LOGGERS', []))
+                       app.config.get('CARAFE_LOGGER_SMTP_ADD_LOGGERS', []))
 
             self.add_handlers(
                 loggers, create_email_handler(app.config))
 
     def add_handlers(self, loggers, handlers):
-        if not isinstance(loggers, list): # pragma: no cover
+        """Attach additional logging handlers to loggers."""
+        if not isinstance(loggers, list):  # pragma: no cover
             loggers = [loggers]
 
-        if not isinstance(handlers, list): # pragma: no cover
+        if not isinstance(handlers, list):  # pragma: no cover
             handlers = [handlers]
 
         for logger in loggers:
@@ -84,15 +92,15 @@ class Logger(object):
                 logger.addHandler(handler)
 
     def __getattr__(self, attr):
-        # proxy attribute calls to current_app.logger as shortcut
+        """Proxy attribute calls to current_app.logger."""
         return getattr(current_app.logger, attr)
 
 
-class HandlerDataMixin(object):
-    '''Mixin class that exposes request data to log format.'''
+class EnvironDataMixin(object):
+    """Mixin class that exposes request data to log format."""
 
     def get_request_environ(self):
-        '''Return copy of request data for debugging purposes.'''
+        """Return copy of request data for debugging purposes."""
         environ = request.environ.copy()
         environ.update({
             'REQUEST_DATA': request.data,
@@ -106,77 +114,83 @@ class HandlerDataMixin(object):
         return environ
 
 
-    def emit(self, record):
-        '''Override parent method and attach request environ data to
-        log record
-        '''
-        record.environ = pformat(self.get_request_environ())
-        super(HandlerDataMixin, self).emit(record)
-
-
-class SMTPHandler(HandlerDataMixin, SMTPHandlerBase):
-    '''Override `emit()` function so that request data is available to log
-    formatter
-    '''
+class SMTPHandler(SMTPHandlerBase, EnvironDataMixin):
+    """Override `emit()` function so that request data is available to log
+    formatter.
+    """
 
     def getSubject(self, record):
-        '''Override with custom subject'''
+        """Override with custom subject."""
         return '[{0}] Application Error: {1}'.format(
             current_app.name, request.url)
 
-
-class RotatingFileHandler(HandlerDataMixin, RotatingFileHandlerBase):
-    '''Override `emit()` function so that request data is available to log
-    formatter
-    '''
-    pass
+    def emit(self, record):
+        """Override parent method and attach request environ data to
+        log record.
+        """
+        record.environ = pformat(self.get_request_environ())
+        super(SMTPHandler, self).emit(record)
 
 
-def create_rotating_file_handler(options):
+class RotatingFileHandler(RotatingFileHandlerBase, EnvironDataMixin):
+    """Override `emit()` function so that request data is available to log
+    formatter.
+    """
+    def emit(self, record):
+        """Override parent method and attach request environ data to
+        log record
+        """
+        record.environ = pformat(self.get_request_environ())
+        super(RotatingFileHandler, self).emit(record)
+
+
+def create_rotating_file_handler(config):
+    """Create a rotating file logger handler."""
     kargs = {
-        'filename': options['CARAFE_LOGGER_RFILE_FILENAME'],
-        'mode': options.get('CARAFE_LOGGER_RFILE_MODE', 'a'),
-        'maxBytes': options.get('CARAFE_LOGGER_RFILE_MAXBYTES', 0),
-        'backupCount': options.get('CARAFE_LOGGER_RFILE_BACKUPCOUNT', 0),
-        'encoding': options.get('CARAFE_LOGGER_RFILE_ENCODING'),
-        'delay': options.get('CARAFE_LOGGER_RFILE_DELAY', 0)
+        'filename': config['CARAFE_LOGGER_RFILE_FILENAME'],
+        'mode': config.get('CARAFE_LOGGER_RFILE_MODE', 'a'),
+        'maxBytes': config.get('CARAFE_LOGGER_RFILE_MAXBYTES', 0),
+        'backupCount': config.get('CARAFE_LOGGER_RFILE_BACKUPCOUNT', 0),
+        'encoding': config.get('CARAFE_LOGGER_RFILE_ENCODING'),
+        'delay': config.get('CARAFE_LOGGER_RFILE_DELAY', 0)
     }
 
     handler = RotatingFileHandler(**kargs)
     handler.setLevel(
-        getattr(logging, options.get('CARAFE_LOGGER_RFILE_LEVEL', 'WARNING')))
+        getattr(logging, config.get('CARAFE_LOGGER_RFILE_LEVEL', 'WARNING')))
 
     handler.setFormatter(Formatter(WARNING_FORMAT))
 
     return handler
 
 
-def create_email_handler(options):
-    if isinstance(options['CARAFE_LOGGER_SMTP_TOADDRS'], basestring):
+def create_email_handler(config):
+    """Create an email logging handler."""
+    if isinstance(config['CARAFE_LOGGER_SMTP_TOADDRS'], basestring):
         # convert to list
-        options['CARAFE_LOGGER_SMTP_TOADDRS'] = [
+        config['CARAFE_LOGGER_SMTP_TOADDRS'] = [
             x.strip()
-            for x in options['CARAFE_LOGGER_SMTP_TOADDRS'].split(',')
+            for x in config['CARAFE_LOGGER_SMTP_TOADDRS'].split(',')
         ]
 
     kargs = {
         'mailhost': (
-            options['CARAFE_LOGGER_SMTP_SERVER'],
-            options['CARAFE_LOGGER_SMTP_PORT']
+            config['CARAFE_LOGGER_SMTP_SERVER'],
+            config['CARAFE_LOGGER_SMTP_PORT']
         ),
-        'fromaddr': options['CARAFE_LOGGER_SMTP_FROMADDR'],
-        'toaddrs': options['CARAFE_LOGGER_SMTP_TOADDRS'],
+        'fromaddr': config['CARAFE_LOGGER_SMTP_FROMADDR'],
+        'toaddrs': config['CARAFE_LOGGER_SMTP_TOADDRS'],
         'subject': 'Application Error',
         'credentials': (
-            options['CARAFE_LOGGER_SMTP_USERNAME'],
-            options['CARAFE_LOGGER_SMTP_PASSWORD']
+            config['CARAFE_LOGGER_SMTP_USERNAME'],
+            config['CARAFE_LOGGER_SMTP_PASSWORD']
         ),
-        'secure': () if options.get('CARAFE_LOGGER_SMTP_USE_TLS') else None
+        'secure': () if config.get('CARAFE_LOGGER_SMTP_USE_TLS') else None
     }
 
     handler = SMTPHandler(**kargs)
     handler.setLevel(
-        getattr(logging, options.get('CARAFE_LOGGER_SMTP_LEVEL', 'ERROR')))
+        getattr(logging, config.get('CARAFE_LOGGER_SMTP_LEVEL', 'ERROR')))
 
     handler.setFormatter(Formatter(ERROR_FORMAT))
 
